@@ -3,8 +3,10 @@ use strict;
 use Text::Xslate;
 use FindBin qw($Bin);
 
+my $path = $Bin;
 my $tx = Text::Xslate->new(
-    path  => ["$Bin/template"],
+    path      => [$path],
+    cache_dir =>  $path,
 );
 
 print $tx->render('hello.tx', { });
