@@ -4,12 +4,12 @@ use warnings;
 use Carp ();
 use Text::Xslate::Util qw(p);
 
-my %methods;
+my %storage;
 
 sub bridge {
     my $class = shift;
     while(my($type, $table) = splice @_, 0, 2) {
-        $methods{$class}{$type} = $table;
+        $storage{$class}{$type} = $table;
     }
     return;
 }
@@ -23,13 +23,13 @@ sub export_into_xslate {
 sub methods {
     my($class, %args) = @_;
 
-    if(!exists $methods{$class}) {
+    if(!exists $storage{$class}) {
         croak("$class has no methods (possibly not a bride class)");
     }
 
     if(exists $args{-exclude}) {
         my $exclude = $args{-exclude};
-        my $methods = $class->_methods;
+        my $methods = $class->_functions;
         my @export;
 
         if(ref($exclude) eq 'ARRAY') {
@@ -48,28 +48,35 @@ sub methods {
         return map { $_ => $methods->{$_} } @export;
     }
     else {
-        return %{ $class->_methods };
+        return %{ $class->_functions };
     }
 }
 
-sub _methods {
+sub _functions {
     my($class) = @_;
 
-    my $storage = $methods{$class}     ||= {};
-    my $methods = $storage->{_methods} ||= {};
+    my $st    = $storage{$class} ||= {};
+    my $funcs = $st->{_funcs}    ||= {};
 
+    # for methods
     foreach my $type qw(scalar hash array) {
-        my $table = $storage->{$type} || next;
+        my $table = $st->{$type} || next;
 
         while(my($name, $body) = each %{$table}) {
-            $methods->{$type . '::' . $name} = $body;
+            $funcs->{$type . '::' . $name} = $body;
         }
     }
-    return $methods;
+
+    # for functions
+    my $table = $st->{function};
+    while(my($name, $body) = each %{$table}) {
+        $funcs->{$name} = $body;
+    }
+    return $funcs;
 }
 
 sub dump {
-    p(\%methods);
+    p(\%storage);
 }
 
 1;
@@ -79,6 +86,8 @@ __END__
 
 Text::Xslate::Bridge - The interface base class to import methods
 
+=for test_synopsis my(%nil_methods, %scalar_methods, %array_methods, %hash_methods, %functions);
+
 =head1 SYNOPSIS
 
     package SomeTemplate::Bridge::Xslate;
@@ -86,10 +95,12 @@ Text::Xslate::Bridge - The interface base class to import methods
     use parent qw(Text::Xslate::Bridge);
 
     __PACKAGE__->bride(
-        nil    => \%SomeTemplate::nil_methods,
-        scalar => \%SomeTemplate::scalar_methods,
-        array  => \%SomeTemplate::array_methods,
-        hash   => \%SomeTemplate::hash_methods,
+        nil    => \%nil_methods,
+        scalar => \%scalar_methods,
+        array  => \%array_methods,
+        hash   => \%hash_methods,
+
+        function => \%functions,
     );
 
     # in your script
